Struct libdrm_amdgpu_sys::AMDGPU::drm_amdgpu_heap_info

source ·
#[repr(C)]
pub struct drm_amdgpu_heap_info { pub total_heap_size: c_ulonglong, pub usable_heap_size: c_ulonglong, pub heap_usage: c_ulonglong, pub max_allocation: c_ulonglong, }

Fields

total_heap_size: c_ulonglong

max. physical memory

usable_heap_size: c_ulonglong

Theoretical max. available memory in the given heap

heap_usage: c_ulonglong

Number of bytes allocated in the heap. This includes all processes and private allocations in the kernel. It changes when new buffers are allocated, freed, and moved. It cannot be larger than heap_size.

max_allocation: c_ulonglong

Theoretical possible max. size of buffer which could be allocated in the given heap